extends Control

@onready var piece_container: HBoxContainer = $PieceContainer

var selected_button: TextureButton = null
var selected_piece: String = ""

func refresh_pieces_display() -> void:
	for child in piece_container.get_children():
		child.queue_free()
		
	var available_pieces = RunData.get_pieces()
	
	for piece in available_pieces:
		var piece_button = create_piece_button(piece)
		piece_container.add_child(piece_button)

# Dynamically creates buttons
func create_piece_button(piece_name: String) -> TextureButton:
	var button = TextureButton.new()
	
	var texture = load("res://assets/sprites/" + piece_name.to_lower() + ".png")
	if texture:
		button.texture_normal = texture
	
	# button properties 
	button.custom_minimum_size = Vector2(64, 64)
	button.stretch_mode = TextureButton.STRETCH_KEEP_ASPECT_CENTERED
	button.tooltip_text = piece_name.capitalize()
	
	# Hover effects to indicate users
	button.mouse_entered.connect(func():
		if button != selected_button:
			button.modulate = Color(1.2, 1.2, 1.2))
	button.mouse_exited.connect(func():
		if button != selected_button:
			button.modulate = Color(1, 1, 1))
	
	button.pressed.connect(func(): _on_piece_button_pressed(button, piece_name))
	
	return button

func _on_piece_button_pressed(pressed_button: TextureButton, piece_name: String) -> void:
	if selected_button:
		selected_button.modulate = Color(1, 1, 1)
		
	if selected_button == pressed_button:
		selected_button = null
		selected_piece = ""
	else:
		selected_button = pressed_button
		selected_button.modulate = Color(0.5, 0.5, 0.5)
		selected_piece = piece_name
	
func get_selected_piece_name() -> String:
	return selected_piece
	
func clear_selection() -> void:
	if selected_button:
		selected_button.modulate = Color(1, 1, 1)
	selected_button = null
	selected_piece = ""
	
func delete_button() -> void:
	selected_button.queue_free()
